#
# spec file for package perl-Mail-Mbox-MessageParser
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Mail-Mbox-MessageParser
Version:        1.5105
Release:        3.1
%define cpan_name Mail-Mbox-MessageParser
Summary:        Fast and Simple Mbox Folder Reader
License:        GPL-2.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Mail-Mbox-MessageParser/
Source0:        http://www.cpan.org/authors/id/D/DC/DCOPPIT/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(File::Path) >= 2.08
BuildRequires:  perl(File::Slurp)
BuildRequires:  perl(FileHandle::Unget)
BuildRequires:  perl(Text::Diff)
BuildRequires:  perl(URI::Escape)
Requires:       perl(FileHandle::Unget)
%{perl_requires}

%description
This module implements a fast but simple mbox folder reader. One of three
implementations (Cache, Grep, Perl) will be used depending on the wishes of
the user and the system configuration. The first implementation is a
cached-based one which stores email information about mailboxes on the file
system. Subsequent accesses will be faster because no analysis of the
mailbox will be needed. The second implementation is one based on GNU grep,
and is significantly faster than the Perl version for mailboxes which
contain very large (10MB) emails. The final implementation is a fast
Perl-based one which should always be applicable.

The Cache implementation is about 6 times faster than the standard Perl
implementation. The Grep implementation is about 4 times faster than the
standard Perl implementation. If you have GNU grep, it's best to enable
both the Cache and Grep implementations. If the cache information is
available, you'll get very fast speeds. Otherwise, you'll take about a 1/3
performance hit when the Grep version is used instead.

The overriding requirement for this module is speed. If you wish more
sophisticated parsing, use Mail::MboxParser (which is based on this module)
or Mail::Box.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc anonymize_mailbox CHANGES LICENSE README TODO

%changelog
* Sun May  3 2015 coolo@suse.com
- updated to 1.5105
  see /usr/share/doc/packages/perl-Mail-Mbox-MessageParser/CHANGES
  Version 1.5105: Sat May 2 2015
  - Prevent CPAN from indexing private-lib
  Version 1.5104: Mon Apr 20 2015
  - Remove unused File::Cat import
  Version 1.5103: Mon Apr 20 2015
  - Add File::Path dependency for testing. Thanks to Paul Howarth
    <paul@city-fan.org> for the info.
    https://rt.cpan.org/Ticket/Display.html?id=103482
  - Don't install private Module::Install extension. Thanks to Paul Howarth
    <paul@city-fan.org> for the bug report.
    https://rt.cpan.org/Ticket/Display.html?id=103482
  - Clarify licensing terms
  - Move verbose testing to a private module, and implement it in a way that
    doesn't require editing the Makefile after it is generated.
  - Require File::Slurp instead of including it, to avoid potential problems
    like this:
    http://www.cpantesters.org/cpan/report/86a0145a-e52b-11e4-a1d1-8536eb4f9f07
  - Improve the ability of the test suite to be run in parallel
  - Fix Windows test incompatibilities, such as:
    http://www.cpantesters.org/cpan/report/12187014-af8d-1014-92d8-fdf72a825c07
    http://www.cpantesters.org/cpan/report/12187014-af8d-1014-92d8-fdf72a825c07
  Version 1.5102: Sun Apr 12 2015
  - Fix xz and lzip test skip for when tools are not installed
  - Enable verbose testing for CPAN-testers
  - Use proper temp dir instead of t/temp
  - Consolidate issue tracking at rt.cpan.org
  Version 1.5101: Sat Apr 4 2015
  - Add a version check for lzip, to make sure the .lz file can be decompressed
    properly during testing. Thanks to Paul Howarth <paul@city-fan.org> for the
    suggestion.
  - Fix warning about deleting nonexistent test cache
  - Enhance "make test TEST_VERBOSE=1" to dump debug information
  - Work around a POD-stripping bug that would cause module load to fail on some
    platforms
  Version 1.5100: Sun Mar 22 2015
  - Moved code to github
  - Added xz support.
    https://rt.cpan.org/Ticket/Display.html?id=68286
    Thanks to sascha@trimind.de for initial patches.
  - Added lzip support.
    Thanks to an anonymous submitter for the idea.
    http://sourceforge.net/p/grepmail/patches/8/
  - Added POD test
  - Fixed hang in pure Perl implementation for a malformed mbox file scenario.
    Thanks to Jason Brooks <jason@petting-zoo.org> for providing an mbox
    that found this bug.
  - Fixed $OLDSTDERR used only once warning.
    https://rt.cpan.org/Ticket/Display.html?id=58053
    Thanks to paul@city-fan.org for the bug report and patch.
  - Fixed enabling of warnings.
    https://rt.cpan.org/Ticket/Display.html?id=79898
    Thanks to atourbin@cpan.org for the bug report and patch.
  - Fixed a division by zero error for malformed mbox files that start with a
    newline.
    https://rt.cpan.org/Ticket/Display.html?id=69469
    Thanks to vadz@cpan.org for the bug report.
  - Fix bug in M::M::Perl documentation.
    Thanks to Christopher Orsolits <chris@s7logic.com> for spotting it.
  - Add more cache file validation.
    Thanks to Richard Higson <richard.higson@gt.owl.de> for reporting the
    problem.
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Mon Jan 25 2010 anicka@suse.cz
- update to 1.5002
  * Disabled the grep interface, which has had some tricky bugs
  that I don't have time to figure out.
  * Updated Makefile.PL to be compatible with versions of
  Module::Install > 0.88.
  * Instead of returning an error for an empty mailbox, a valid
  mailbox is returned that will immediately fail the
  end_of_mailbox check. This should simplify people's code.
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Thu Feb 21 2008 anicka@suse.cz
- fix build with perl 5.10
* Mon Jan 15 2007 anicka@suse.cz
- update to 1.5000
  * The Cache and Grep implementations now detect when changes
    have occurred to the file being parsed, and automatically
    invalidate their cache values and revert to the Perl
    implementation. NOTE: This works well for appending to
    the mailbox, but undefined behavior occurs if modifications are
    made to the mailbox at locations earlier than the current
    position.
  * Changed the reset test so that it doesn't create output with
    inconsistent line endings in the case of a dos mailbox.
  * Fixed a bug where occasionally the reading of the next email
    will go into an infinite loop when reading from standard input.
  * read_next_email now returns undef on end of file.
  * Simplified code by removing end_of_file attribute of parser
    objects.
* Thu Sep 14 2006 anicka@suse.cz
- update to 1.4005
  * Fixed a bug where emails with a line near the end that start
    with "From " would cause the Grep implementation to go into
    an infinite loop.
  * Fixed some minor coding style issues.
* Wed Jul 12 2006 anicka@suse.cz
- update to 1.4004
  * Fixed a bug where, when emails are incomplete, the Perl parser
    would cache incorrect information, causing the Cache
    implementation to go into an infinite loop when it tried
    to use the invalid information.
  * Improved the behavior for multi-part emails that lack a valid
    ending boundaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Aug  3 2005 cthiel@suse.de
- update to version 1.4001
* Sun Jul 31 2005 cthiel@suse.de
- update to version 1.4000
* Mon Jul 18 2005 rommel@suse.de
- update to version 1.2130 (requirement by grepmail)
* Tue Jun 22 2004 rommel@suse.de
- initial checkin
